@@ -19,6 +19,28 @@ pub enum CiFormat {
     Jenkins,
 }
 
+/// SBOM format options
+#[derive(ValueEnum, Clone, Debug)]
+pub enum SbomFormat {
+    /// SPDX format
+    Spdx,
+    /// CycloneDX format
+    Cyclonedx,
+    /// Generate all supported formats
+    All,
+}
+
+/// OSI filter options
+#[derive(ValueEnum, Clone, Debug)]
+pub enum OsiFilter {
+    /// Show only OSI approved licenses
+    Approved,
+    /// Show only non-OSI approved licenses
+    NotApproved,
+    /// Show licenses with unknown OSI status
+    Unknown,
+}
+
 /// CLI Commands
 #[derive(Subcommand, Debug, Clone)]
 pub enum Commands {
@@ -132,6 +154,14 @@ pub struct Cli {
     // Show a concise gist summary
     #[arg(long, group = "output")]
     pub gist: bool,
+
+    /// Generate SBOM in specified format
+    #[arg(long, value_enum)]
+    pub sbom: Option<SbomFormat>,
+
+    /// Filter by OSI license approval status
+    #[arg(long, value_enum)]
+    pub osi: Option<OsiFilter>,
 }
 
 impl Cli {
@@ -381,6 +411,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         assert_eq!(cli.path, "./");
@@ -417,6 +449,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         let cmd = cli.get_command_args();
@@ -457,6 +491,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         let cmd = cli.get_command_args();
