@@ -6,6 +6,7 @@ mod languages;
 mod licenses;
 mod parser;
 mod reporter;
+mod sbom;
 mod table;
 mod utils;
 
@@ -16,6 +17,7 @@ use generate::handle_generate_command;
 use licenses::{detect_project_license, is_license_compatible, LicenseCompatibility};
 use parser::parse_root;
 use reporter::{generate_report, ReportConfig};
+use sbom::handle_sbom_command;
 use std::env;
 use std::path::Path;
 use std::process;
@@ -40,6 +42,7 @@ struct CheckConfig {
     fail_on_incompatible: bool,
     project_license: Option<String>,
     gist: bool,
+    osi: Option<cli::OsiFilter>,
 }
 
 fn main() {
@@ -109,6 +112,15 @@ fn run() -> FeludaResult<()> {
         &format!("Analysing project at: {}", analysis_path.display()),
     );
 
+    // Handle SBOM generation if requested
+    if let Some(sbom_format) = &args.sbom {
+        return handle_sbom_command(
+            analysis_path.to_string_lossy().to_string(),
+            sbom_format,
+            args.output_file.clone(),
+        );
+    }
+
     // Handle the command based on whether a subcommand was provided
     if args.is_default_command() {
         // Default behavior: license analysis
@@ -127,6 +139,7 @@ fn run() -> FeludaResult<()> {
             fail_on_incompatible: args.fail_on_incompatible,
             project_license: args.project_license,
             gist: args.gist,
+            osi: args.osi,
         };
         handle_check_command(config)
     } else {
@@ -319,6 +332,47 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
             }
         }
 
+        // Apply OSI filtering
+        if let Some(osi_filter) = &config.osi {
+            let before_count = analyzed_data.len();
+            match osi_filter {
+                cli::OsiFilter::Approved => {
+                    analyzed_data.retain(|info| info.osi_status == licenses::OsiStatus::Approved);
+                    log(
+                        LogLevel::Info,
+                        &format!(
+                            "Filtered for OSI approved licenses: {} of {} dependencies",
+                            analyzed_data.len(),
+                            before_count
+                        ),
+                    );
+                }
+                cli::OsiFilter::NotApproved => {
+                    analyzed_data
+                        .retain(|info| info.osi_status == licenses::OsiStatus::NotApproved);
+                    log(
+                        LogLevel::Info,
+                        &format!(
+                            "Filtered for non-OSI approved licenses: {} of {} dependencies",
+                            analyzed_data.len(),
+                            before_count
+                        ),
+                    );
+                }
+                cli::OsiFilter::Unknown => {
+                    analyzed_data.retain(|info| info.osi_status == licenses::OsiStatus::Unknown);
+                    log(
+                        LogLevel::Info,
+                        &format!(
+                            "Filtered for unknown OSI status licenses: {} of {} dependencies",
+                            analyzed_data.len(),
+                            before_count
+                        ),
+                    );
+                }
+            }
+        }
+
         log(LogLevel::Info, "Starting TUI mode");
 
         // Initialize the terminal
@@ -350,6 +404,7 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
             config.output_file,
             project_license,
             config.gist,
+            config.osi,
         );
 
         // Generate a report based on the analyzed data
