@@ -2,10 +2,13 @@
 
 use crate::cli;
 use crate::debug::{log, log_debug, FeludaResult, LogLevel};
-use crate::languages::{Language, PYTHON_PATHS};
-use crate::licenses::{LicenseCompatibility, LicenseInfo};
+use crate::languages::{Language, CPP_PATHS, C_PATHS, PYTHON_PATHS};
+use crate::licenses::{
+    detect_project_license, is_license_compatible, LicenseCompatibility, LicenseInfo,
+};
 use cargo_metadata::MetadataCommand;
 use ignore::Walk;
+use rayon::prelude::*;
 use std::path::{Path, PathBuf};
 
 /// Project root information
@@ -75,6 +78,52 @@ fn find_project_roots(root_path: impl AsRef<Path>) -> FeludaResult<Vec<ProjectRo
     Ok(project_roots)
 }
 
+/// Check which C project file exists in the given path
+fn check_which_c_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
+    for &path in C_PATHS.iter() {
+        let full_path = Path::new(project_path.as_ref()).join(path);
+        if full_path.exists() {
+            log(
+                LogLevel::Info,
+                &format!("Found C project file: {}", full_path.display()),
+            );
+            return Some(path.to_string());
+        }
+    }
+
+    log(
+        LogLevel::Warn,
+        &format!(
+            "No C project file found in: {}",
+            project_path.as_ref().display()
+        ),
+    );
+    None
+}
+
+/// Check which C++ project file exists in the given path
+fn check_which_cpp_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
+    for &path in CPP_PATHS.iter() {
+        let full_path = Path::new(project_path.as_ref()).join(path);
+        if full_path.exists() {
+            log(
+                LogLevel::Info,
+                &format!("Found C++ project file: {}", full_path.display()),
+            );
+            return Some(path.to_string());
+        }
+    }
+
+    log(
+        LogLevel::Warn,
+        &format!(
+            "No C++ project file found in: {}",
+            project_path.as_ref().display()
+        ),
+    );
+    None
+}
+
 /// Check which Python project file exists in the given path
 fn check_which_python_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
     for &path in PYTHON_PATHS.iter() {
@@ -102,6 +151,16 @@ fn check_which_python_file_exists(project_path: impl AsRef<Path>) -> Option<Stri
 pub fn parse_root(
     root_path: impl AsRef<Path>,
     language: Option<&str>,
+) -> FeludaResult<Vec<LicenseInfo>> {
+    let config = crate::config::load_config()?;
+    parse_root_with_config(root_path, language, &config)
+}
+
+/// Main entry point for parsing project dependencies
+pub fn parse_root_with_config(
+    root_path: impl AsRef<Path>,
+    language: Option<&str>,
+    config: &crate::config::FeludaConfig,
 ) -> FeludaResult<Vec<LicenseInfo>> {
     log(
         LogLevel::Info,
@@ -120,69 +179,89 @@ pub fn parse_root(
         );
         println!(
             "❌ No supported project files found.\n\
-            Feluda supports: Rust, Node.js, Go, Python"
+            Feluda supports: C, C++, Rust, Node.js, Go, Python"
         );
         return Ok(Vec::new());
     }
 
-    let mut licenses = Vec::new();
+    let licenses: Vec<LicenseInfo> = project_roots
+        .into_par_iter()
+        .filter_map(|root| {
+            if let Some(language) = language {
+                if !matches_language(root.project_type, language) {
+                    log(
+                        LogLevel::Info,
+                        &format!(
+                            "Skipping {:?} project (language filter: {})",
+                            root.project_type, language
+                        ),
+                    );
+                    return None;
+                }
+            }
 
-    for root in project_roots {
-        if let Some(language) = language {
-            if !matches_language(root.project_type, language) {
-                log(
-                    LogLevel::Info,
-                    &format!(
-                        "Skipping {:?} project (language filter: {})",
-                        root.project_type, language
-                    ),
-                );
-                continue;
+            match parse_dependencies(&root, config) {
+                Ok(deps) => {
+                    log(
+                        LogLevel::Info,
+                        &format!(
+                            "Found {} dependencies in {}",
+                            deps.len(),
+                            root.path.display()
+                        ),
+                    );
+                    Some(deps)
+                }
+                Err(err) => {
+                    log(
+                        LogLevel::Error,
+                        &format!(
+                            "Error parsing dependencies in {}: {}",
+                            root.path.display(),
+                            err
+                        ),
+                    );
+                    None
+                }
             }
-        }
-
-        match parse_dependencies(&root) {
-            Ok(mut deps) => {
-                log(
-                    LogLevel::Info,
-                    &format!(
-                        "Found {} dependencies in {}",
-                        deps.len(),
-                        root.path.display()
-                    ),
-                );
-                licenses.append(&mut deps);
-            }
-            Err(err) => {
-                log(
-                    LogLevel::Error,
-                    &format!(
-                        "Error parsing dependencies in {}: {}",
-                        root.path.display(),
-                        err
-                    ),
-                );
-            }
-        }
-    }
+        })
+        .flatten()
+        .collect();
 
     log(
         LogLevel::Info,
         &format!("Total dependencies found: {}", licenses.len()),
     );
 
-    for license in &mut licenses {
-        license.compatibility = LicenseCompatibility::Unknown;
-    }
+    // Set license compatibility based on project license
+    let project_license =
+        detect_project_license(root_path.as_ref().to_str().unwrap_or("")).unwrap_or(None);
+
+    let mut licenses = licenses;
+    set_license_compatibility(&mut licenses, &project_license);
 
     Ok(licenses)
 }
 
+/// Set license compatibility for all dependencies
+fn set_license_compatibility(licenses: &mut [LicenseInfo], project_license: &Option<String>) {
+    for license in licenses {
+        license.compatibility = match (project_license, &license.license) {
+            (Some(proj_license), Some(dep_license)) => {
+                is_license_compatible(dep_license, proj_license)
+            }
+            _ => LicenseCompatibility::Unknown,
+        };
+    }
+}
+
 /// Check if a project type matches the given language filter
 fn matches_language(project_type: Language, language: &str) -> bool {
     matches!(
         (project_type, language.to_lowercase().as_str()),
-        (Language::Rust(_), "rust")
+        (Language::C(_), "c")
+            | (Language::Cpp(_), "cpp" | "c++")
+            | (Language::Rust(_), "rust")
             | (Language::Node(_), "node")
             | (Language::Go(_), "go")
             | (Language::Python(_), "python")
@@ -190,7 +269,10 @@ fn matches_language(project_type: Language, language: &str) -> bool {
 }
 
 /// Parse dependencies based on the project type
-fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
+fn parse_dependencies(
+    root: &ProjectRoot,
+    config: &crate::config::FeludaConfig,
+) -> FeludaResult<Vec<LicenseInfo>> {
     let project_path = &root.path;
     let project_type = root.project_type;
 
@@ -219,14 +301,7 @@ fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
                             metadata.packages.len()
                         ));
 
-                        let mut license_info =
-                            crate::languages::analyze_rust_licenses(metadata.packages);
-
-                        for info in &mut license_info {
-                            info.compatibility = LicenseCompatibility::Unknown;
-                        }
-
-                        license_info
+                        crate::languages::analyze_rust_licenses(metadata.packages)
                     }
                     Err(err) => {
                         log(
@@ -248,12 +323,7 @@ fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
 
                 match project_path.to_str() {
                     Some(path_str) => {
-                        let mut deps = crate::languages::analyze_js_licenses(path_str);
-
-                        for info in &mut deps {
-                            info.compatibility = LicenseCompatibility::Unknown;
-                        }
-
+                        let deps = crate::languages::analyze_js_licenses(path_str);
                         indicator.update_progress(&format!("found {} dependencies", deps.len()));
                         deps
                     }
@@ -274,12 +344,7 @@ fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
 
                 match project_path.to_str() {
                     Some(path_str) => {
-                        let mut deps = crate::languages::analyze_go_licenses(path_str);
-
-                        for info in &mut deps {
-                            info.compatibility = LicenseCompatibility::Unknown;
-                        }
-
+                        let deps = crate::languages::analyze_go_licenses(path_str, config);
                         indicator.update_progress(&format!("found {} dependencies", deps.len()));
                         deps
                     }
@@ -301,12 +366,7 @@ fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
 
                     match project_path.to_str() {
                         Some(path_str) => {
-                            let mut deps = crate::languages::analyze_python_licenses(path_str);
-
-                            for info in &mut deps {
-                                info.compatibility = LicenseCompatibility::Unknown;
-                            }
-
+                            let deps = crate::languages::analyze_python_licenses(path_str, config);
                             indicator
                                 .update_progress(&format!("found {} dependencies", deps.len()));
                             deps
@@ -322,6 +382,62 @@ fn parse_dependencies(root: &ProjectRoot) -> FeludaResult<Vec<LicenseInfo>> {
                     Vec::new()
                 }
             },
+            Language::C(_) => match check_which_c_file_exists(project_path) {
+                Some(c_build_file) => {
+                    let project_path = Path::new(project_path).join(&c_build_file);
+                    log(
+                        LogLevel::Info,
+                        &format!("Parsing C project: {}", project_path.display()),
+                    );
+
+                    indicator.update_progress(&format!("analyzing {c_build_file}"));
+
+                    match project_path.to_str() {
+                        Some(path_str) => {
+                            let deps = crate::languages::analyze_c_licenses(path_str, config);
+                            indicator
+                                .update_progress(&format!("found {} dependencies", deps.len()));
+                            deps
+                        }
+                        None => {
+                            log(LogLevel::Error, "Failed to convert C path to string");
+                            Vec::new()
+                        }
+                    }
+                }
+                None => {
+                    log(LogLevel::Error, "C build file not found");
+                    Vec::new()
+                }
+            },
+            Language::Cpp(_) => match check_which_cpp_file_exists(project_path) {
+                Some(cpp_build_file) => {
+                    let project_path = Path::new(project_path).join(&cpp_build_file);
+                    log(
+                        LogLevel::Info,
+                        &format!("Parsing C++ project: {}", project_path.display()),
+                    );
+
+                    indicator.update_progress(&format!("analyzing {cpp_build_file}"));
+
+                    match project_path.to_str() {
+                        Some(path_str) => {
+                            let deps = crate::languages::analyze_cpp_licenses(path_str, config);
+                            indicator
+                                .update_progress(&format!("found {} dependencies", deps.len()));
+                            deps
+                        }
+                        None => {
+                            log(LogLevel::Error, "Failed to convert C++ path to string");
+                            Vec::new()
+                        }
+                    }
+                }
+                None => {
+                    log(LogLevel::Error, "C++ build file not found");
+                    Vec::new()
+                }
+            },
         }
     });
 
@@ -334,6 +450,13 @@ mod tests {
 
     #[test]
     fn test_matches_language() {
+        assert!(matches_language(Language::C(&C_PATHS), "c"));
+        assert!(matches_language(Language::C(&C_PATHS), "C"));
+
+        assert!(matches_language(Language::Cpp(&CPP_PATHS), "cpp"));
+        assert!(matches_language(Language::Cpp(&CPP_PATHS), "c++"));
+        assert!(matches_language(Language::Cpp(&CPP_PATHS), "CPP"));
+
         assert!(matches_language(Language::Rust("Cargo.toml"), "rust"));
         assert!(matches_language(Language::Rust("Cargo.toml"), "RUST"));
         assert!(matches_language(Language::Rust("Cargo.toml"), "Rust"));
@@ -354,9 +477,11 @@ mod tests {
         assert!(!matches_language(Language::Node("package.json"), "python"));
         assert!(!matches_language(Language::Go("go.mod"), "rust"));
         assert!(!matches_language(Language::Python(&PYTHON_PATHS), "go"));
+        assert!(!matches_language(Language::C(&C_PATHS), "cpp"));
+        assert!(!matches_language(Language::Cpp(&CPP_PATHS), "c"));
 
         assert!(!matches_language(Language::Rust("Cargo.toml"), "java"));
-        assert!(!matches_language(Language::Node("package.json"), "cpp"));
+        assert!(!matches_language(Language::Node("package.json"), "java"));
     }
 
     #[test]
@@ -525,7 +650,8 @@ mod tests {
         )
         .unwrap();
 
-        let result = parse_dependencies(&rust_project_root);
+        let config = crate::config::FeludaConfig::default();
+        let result = parse_dependencies(&rust_project_root, &config);
         assert!(result.is_ok());
         let licenses = result.unwrap();
         assert!(licenses.is_empty());
@@ -543,7 +669,8 @@ mod tests {
         // Create invalid package.json
         std::fs::write(temp_dir.path().join("package.json"), "invalid json content").unwrap();
 
-        let result = parse_dependencies(&node_project_root);
+        let config = crate::config::FeludaConfig::default();
+        let result = parse_dependencies(&node_project_root, &config);
         assert!(result.is_ok());
         let licenses = result.unwrap();
         assert!(licenses.is_empty());
@@ -561,7 +688,8 @@ mod tests {
         // Create empty requirements.txt
         std::fs::write(temp_dir.path().join("requirements.txt"), "").unwrap();
 
-        let result = parse_dependencies(&python_project_root);
+        let config = crate::config::FeludaConfig::default();
+        let result = parse_dependencies(&python_project_root, &config);
         assert!(result.is_ok());
         let licenses = result.unwrap();
         assert!(licenses.is_empty());
