@@ -437,6 +437,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         let result = clone_repository(&args, temp_dir.path());
@@ -489,6 +491,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         // Enable debug mode for this test
@@ -540,6 +544,8 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
+            sbom: None,
+            osi: None,
         };
 
         let result = clone_repository(&args, temp_dir.path());
